require 'spec_helper'
require 'bonanza/call_link_helpers'

class FakeCallLinkHelpersClass
  include Bonanza::CallLinkHelpers
end

RSpec.describe FakeCallLinkHelpersClass do
  subject { described_class.new }

  describe '#call_to' do
    subject { super().call_to(phone_number) }

    context 'valid phone number' do
      let(:phone_number) { '+41123456789' }

      it 'generates a link to the phone call service' do
        expect(subject).to eq(
          '<a href="http://pbx.nine.ch/call.php?ext=0041123456789">+41123456789</a>'
        )
      end

      it 'replaces the + sign with 00' do
        expect(subject).to include '0041123456789'
      end
    end

    context 'phone number with unnecessary spaces' do
      let(:phone_number) { '+41 12 34 56 78 91' }

      it 'removes the unnecessary spaces' do
        expect(subject.to_s).to include '0041123456789'
      end
    end

    describe 'invalid phone numbers' do
      context 'empty phone number' do
        let(:phone_number) { '' }

        specify { expect(subject).to eq '' }
      end

      context 'nil phone number' do
        let(:phone_number) { nil }

        specify { expect(subject).to eq '' }
      end
    end
  end
end
