require 'bonanza/link_strategies/base'

RSpec.describe Bonanza::LinkStrategies::Base do
  let(:strategy) { Bonanza::LinkStrategies::Base.new }
  let(:environment) { 'production' }

  before do
    allow(strategy).to receive(:environment).and_return(environment)
  end

  describe '#app' do
    it 'uses the class name as app name' do
      expect(strategy.app).to eq 'base'
    end
  end

  describe '#domain' do
    subject { strategy.domain }

    context 'for dev environment' do
      let(:environment) { 'development' }
      it { should eq 'http://base.dev' }
    end

    context 'for test environment' do
      let(:environment) { 'test' }
      it { should eq 'http://base.test' }
    end

    context 'for staging environment' do
      let(:environment) { 'staging' }
      it { should eq 'https://base-staging.nine.ch' }
    end

    context 'for production environment' do
      let(:environment) { 'production' }
      it { should eq 'https://base.nine.ch' }
    end
  end

  describe '#url_to' do
    before do
      allow(strategy).to receive(:paths).and_return(account: '/accounts/%{reference}')
    end

    it 'constructs a correct url' do
      expect(strategy.url_to(:account, '1234')).to eq 'https://base.nine.ch/accounts/1234'
    end
  end
end
