# encoding: utf-8

require 'spec_helper'
require 'bonanza/validators/domain_name_validator'

RSpec.describe Bonanza::Validators::DomainNameValidator do
  class Domain
    include ActiveModel::Validations
    include Bonanza::Validators

    attr_accessor :name
    validates :name, domain_name: true
  end

  subject { Domain.new }

  [
    'domain.com',
    '4domain.com',
    'www.domain.ch',
    'sub.domain.domain.co.uk',
    '1234.ch',
    'sasie.diamonds',
    'äää.com',
    'putzy-the-bear.co.uk',
    'موقع.وزارة-الاتصالات.مصر',
    '🐩💩.com',
    'busi.katze', # we don't care about validity of tlds
  ].each do |domain_name|
    it "#{domain_name} is valid" do
      subject.name = domain_name
      expect(subject).to be_valid
    end
  end

  describe 'invalid domain name' do
    it 'displays the correct error message' do
      subject.name = 'grosser bruder'

      subject.valid?

      expect(subject.errors[:name]).to match_array('not a valid domain name')
    end

    [
      'yolo',
      'grosser bruder',
      12345,
      'yolo.c',
      '$$.com', # might not be valid but we don't care
    ].each do |domain_name|
      it "#{domain_name} is not valid" do
        subject.name = domain_name

        expect(subject).to_not be_valid
      end
    end
  end
end
