require 'spec_helper'
require 'bonanza/validators/otrs_number_validator'

RSpec.describe Bonanza::Validators::OtrsNumberValidator do
  class Order
    include ActiveModel::Validations
    include Bonanza::Validators

    attr_accessor :otrs_ticket
    validates :otrs_ticket, otrs_number: true
  end

  subject { Order.new }

  it 'passes when the otrs ticket is a 16-character string of numbers' do
    subject.otrs_ticket = '1234567812345678'
    expect(subject).to be_valid
  end

  it 'passes when the otrs ticket is a 16-digit number' do
    subject.otrs_ticket = 1234567812345678

    expect(subject).to be_valid
  end

  describe 'invalid OTRS ticket' do
    it 'displays the correct error message' do
      subject.otrs_ticket = 'abcdefgh12345678'

      subject.valid?

      expect(subject.errors[:otrs_ticket]).to match_array('not an OTRS number')
    end

    it 'fails when it has invalid characters' do
      subject.otrs_ticket = 'abcdefgh12345678'

      expect(subject).to_not be_valid
    end

    it 'fails when it has too few numbers' do
      subject.otrs_ticket = '12345678'

      expect(subject).to_not be_valid
    end

    it 'fails when the ticket includes 16-digits but is longer' do
      subject.otrs_ticket = '123456789123456789'

      expect(subject).to_not be_valid
    end
  end
end
