require 'spec_helper'
require 'bonanza/validators/urn_validator'

RSpec.describe Bonanza::Validators::UrnValidator do
  class Product
    include ActiveModel::Validations
    include Bonanza::Validators

    attr_accessor :urn
    validates :urn, urn: true
  end

  subject { Product.new }

  it 'is valid with correct syntax and type' do
    subject.urn = 'urn:nine:vserver:1234'

    expect(subject).to be_valid
  end

  describe 'invalid URN' do
    it 'displays the correct error message' do
      subject.urn = 'urn:nine:serrrrrver:123'

      subject.valid?

      expect(subject.errors[:urn]).to match_array('invalid URN')
    end

    it 'is invalid if type is not correct' do
      subject.urn = 'urn:nine:serrrrrver:123'

      expect(subject).to be_invalid
    end

    it 'is invalid if syntax is garbage' do
      subject.urn = 'garbage::syntax'

      expect(subject).to be_invalid
    end

    it 'is invalid if empty' do
      subject.urn = ''

      expect(subject).to be_invalid
    end
  end

  context 'allow_empty true' do
    class OtherProduct
      include ActiveModel::Validations
      include Bonanza::Validators

      attr_accessor :urn
      validates :urn, urn: { allow_empty: true }
    end

    it 'is valid if empty' do
      product = OtherProduct.new
      product.urn = ''
      expect(product).to be_valid
    end
  end
end
